@@ -1,8 +1,9 @@
 #[export]
 cls <- function(y, x, R, ca) {
-  xxs <- solve( crossprod(x) )
+
+  xxs <- solve(crossprod(x))
   bols <- xxs %*% crossprod(x, y)
-  bcls <- bols - xxs %*% R %*% solve( R %*% xxs %*% R, R %*% bols - ca )
+  bcls <- bols - xxs %*% R %*% solve(R %*% xxs %*% R, R %*% bols - ca)
   list(bols = bols, bcls = bcls)
 }
 
@@ -36,7 +37,9 @@ het.lmfit <- function(x, y, type = 1) {
 gammareg <- function(y, x, tol = 1e-07, maxiters = 100) {
   mod <- Rfast::gammacon(y)
   x <- model.matrix( y~., data.frame(x) )
-  .Call(Rfast2_gamma_reg, Y = y, X = x, mod = mod, tol = tol, maxiters = maxiters) 
+  mod <- .Call(Rfast2_gamma_reg, Y = y, X = x, mod = mod, tol = tol, maxiters = maxiters) 
+  colnames(mod$be) <- colnames(x)
+  mod  
 }
 
 
@@ -85,6 +88,7 @@ gumbel.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
     exp_z <- exp(-z)  
     lik2 <-  - n * log(s) - sum(z) - sum(exp_z)
   }
+  names(be) <- colnames(x)
   list(be = be, sigma = s, loglik = lik2, iters = i)
 }
 
@@ -112,6 +116,7 @@ negbin.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
   x <- model.matrix( y ~. , data.frame(x) )
   mod <- .Call( Rfast2_negbin_reg,y, x, tol, maxiters)
   names(mod$info) <- c( "iters", "BIC", "log-likelihood", "dispersion" )
+  names(mod$be) <- colnames(x)
   list(info = mod$info, be = mod$be)
 }  
 
@@ -153,6 +158,7 @@ ztp.reg <- function(y, x, full = FALSE, tol = 1e-07, maxiters = 100) {
     xexb <- x * exb
     lik2 <- sum(y * xb) - sum( log( expm1(exb) ) )
   }
+  names(be) <- colnames(x) 
   res <- list( be = be, loglik = lik2 - con, iter = i )
   if (full) {
     se <- chol2inv( chol(der2) )
@@ -191,8 +197,9 @@ hp.reg <- function(y, x, full = FALSE, tol = 1e-07, maxiters = 100) {
   id <- which(y > 0)
   y1[id] <- 1
   prob <- Rfast::glm_logistic(x, y1, full = full, tol = tol, maxiters = maxiters)
-  x <- model.matrix( y ~. , data.frame(x) )
-  mod <- Rfast2::ztp.reg(y[id], x[id, -1], full = full, tol = tol, maxiters = maxiters)
+  x <- model.matrix(y~., data = as.data.frame(x) )
+  mod <- Rfast2::ztp.reg(y[id], x[id, -1, drop = FALSE], full = full, tol = tol, maxiters = maxiters)
+  names(mod$be) <- colnames(x)
   list(prob = prob, mod = mod)
 }
   
@@ -230,6 +237,7 @@ hellinger.countreg <- function(y, x, tol = 1e-07, maxiters = 100) {
     com <- sqy - sqm
     d2 <- sum( com^2 )
   }
+  names(be) <- colnames(x) 
   A <- crossprod( x * com * sqm )
   B <- solve(derb2)
   covbe <- B %*% A %*% B
@@ -301,7 +309,7 @@ sclr <- function(y, x, full = FALSE, tol = 1e-07, maxiters = 100) {
     etheta <- exp(theta)
     lik2 <- theta * sy - sum( log1p(eb) ) - n * log1p(etheta) + sum( y0 * log1p( eb * (1 + etheta) ) )
   } 
-  
+  names(be) <- colnames(x)
   res <- list(theta = theta, be = be, loglik = lik2, iters = i)
   if (full) {
     se <- sqrt( diag( solve( abs( der2 ) ) ) )
@@ -461,6 +469,7 @@ tobit.reg <- function(y, x, ylow = 0, full = FALSE, tol = 1e-07, maxiters = 100)
     lik2 <-  - n1 * log(s) + sum( log( dnorm( e1 / s) ) ) + sum( log( pnorm( e0 / s) ) ) 
   }
   names(lik2) <- NULL
+  names(be) <- colnames(x)
   res <- list(be = be, s = s, loglik = lik2, iters = i)
   if ( full ) {
      se <- solve( der2 )
@@ -510,6 +519,7 @@ binom.reg <- function(y, ni, x, full = FALSE, tol = 1e-07, maxiters = 100) {
     d2 <-  sum( ni * log1p( exp(est) ) ) - sum(y * est)
   }
   devi <- 2 * d2 + con 
+  names(be) <- colnames(x)
   res <- list(be = be, devi = devi)
   if (full) {
     se <- solve(der2)
@@ -525,11 +535,10 @@ binom.reg <- function(y, ni, x, full = FALSE, tol = 1e-07, maxiters = 100) {
 }  
    
 
-
 #[export]
 propols.reg <- function(y, x, cov = FALSE, tol = 1e-07 ,maxiters = 100) {
-  x <- model.matrix(y ~., data.frame(x) )
-  
+
+  x <- model.matrix(y ~., data.frame(x) ) 
   seb <- NULL
   covb <- NULL
   be <- solve( crossprod(x, x), crossprod(x, log(y + 0.5)) )
@@ -562,98 +571,17 @@ propols.reg <- function(y, x, cov = FALSE, tol = 1e-07 ,maxiters = 100) {
 	B <- solve(der2)
     covb <- B %*% A %*% B
     seb <- sqrt( diag(covb) ) 	
-  }	
+  }
+  names(be) <- colnames(x)  
   list(be = be, seb = seb, covb = covb, sse = a2, iters = i)
 }
 
 #[export]
-propjs.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
-  
-  x <- model.matrix(~., data.frame(x) )
-  n <- dim(x)[1]
-  p <- mean(y)
-  be <- c( log(p / (1 - p ) ), numeric(dim(x)[2] - 1) )
-  d1 <- sum( (y + p) * log(y + p) ) + n * p * log(2 * p) + n * (1 - p) * log(1 - p) - sum( (2 - y - p) * log(2 - y - p) )
- 
-  .e3 <-  1/p - 1   ## as.vector( exp(-x %*% be) )
-  .e4 <- 1 + .e3
-  .e5 <- .e4^2
-  .e6 <- 1/.e4
-  .e7 <- .e6 + y
-  com <- ( - log(1 - .e6) + log(.e7) + 2.693147 - log1p(.e3) + log(2 - .e7) ) * .e3/.e5 
-  der <- Rfast::eachcol.apply(x, com) 
-
-  ## der <-  -Rfast::eachcol.apply( x, (1 + log(1 - .e6)) * com ) + Rfast::eachcol.apply( x, (1 + log(.e7)) * com ) + 
-  ## Rfast::eachcol.apply( x, (1.693147 - log1p(.e3)) * com) + Rfast::eachcol.apply( x, ( 1 + log(2 - .e7) ) * com )
-  
-  .e5 <- 1/.e4
-  .e6 <- .e5 + y
-  .e7 <- .e4^2
-  .e9 <- 1 - .e5
-  .e10 <- 2 - .e6
-  .e11 <- 1 + log(.e6)
-  .e12 <- log(.e9)
-  .e13 <- log(.e10)
-  .e14 <- log1p(.e3)
-  com34 <- .e3/.e4
-  com37 <- .e3/.e7
-  com <- .e11 + .e13 -.e12 - .e14
-  a2 <- ( ( 4.386294 + 2 * com + 1/(.e9 * .e4) + 1/(.e4 * .e6) - 1/(.e4 * .e10) ) * com34 - 1.693147 - com ) * com37
-  der2 <- crossprod(x * a2, x)
-
-  ## der2 <- crossprod( x * ( (1 + 2 * (1.693147 - .e14)) * com34 + .e14 - 1.693147 ) * com37, x) + 
-  ## crossprod( x * ( (1/(.e9 * .e4) - 2 * (1 + .e12)) * com34 + 1 + .e12) * com37, x ) + 
-  ## crossprod( x * ( (1/(.e4 * .e6) + 2 * .e11) * com34 - .e11) * com37, x ) - 
-  ## crossprod( x * ( (1/(.e4 * .e10) - 2 * (1 + .e13)) * com34 + 1 + .e13) * com37, x )
-
-  be <- be - solve(der2, der)
-  p <- 1 / ( 1 + exp(-x %*% be) )
-  d2 <- sum( (y + p) * log(y + p) ) + sum( p * log(2 * p) ) + sum( (1 - p) * log(1 - p) ) - 
-  sum( (2 - y - p) * log(2 - y - p) )
-
-  i <- 2
-  while ( d1 - d2 > tol  &  i < maxiters) {
-    i <- i + 1
-    d1 <- d2
-    .e3 <- as.vector( exp(-x %*% be) )
-    .e4 <- 1 + .e3
-    .e5 <- .e4^2
-    .e6 <- 1/.e4
-    .e7 <- .e6 + y
-    com <- ( - log(1 - .e6) + log(.e7) + 2.693147 - log1p(.e3) + log(2 - .e7) ) * .e3/.e5 
-    der <- Rfast::eachcol.apply(x, com) 
-
-    .e5 <- 1/.e4
-    .e6 <- .e5 + y
-    .e7 <- .e4^2
-    .e9 <- 1 - .e5
-    .e10 <- 2 - .e6
-    .e11 <- 1 + log(.e6)
-    .e12 <- log(.e9)
-    .e13 <- log(.e10)
-    .e14 <- log1p(.e3)
-    com34 <- .e3/.e4
-    com37 <- .e3/.e7
-    com <- .e11 + .e13 -.e12 - .e14
-    a2 <- ( ( 4.386294 + 2 * com + 1/(.e9 * .e4) + 1/(.e4 * .e6) - 1/(.e4 * .e10) ) * com34 - 1.693147 - com ) * com37
-    der2 <- crossprod(x * a2, x)
-   
-    be <- be - solve(der2, der)
-    p <- 1 / ( 1 + exp(-x %*% be) )
-    d2 <- sum( (y + p) * log(y + p) ) + sum( p * log(2 * p) ) + sum( (1 - p) * log(1 - p) ) - 
-    sum( (2 - y - p) * log(2 - y - p) )
-
-  }
-  list(be = be, der2 = der2, js = d2, iters = i) 
-}
-
-
-
-
-#[export]
-prophelling.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
+prophelling.reg <- function(y, x, cov = FALSE, tol = 1e-07, maxiters = 100) {
 
   x <- model.matrix( y~., data.frame(x) )
+  seb <- NULL
+  covb <- NULL
   sqy <- sqrt(y)
   dm <- dim(x)
   n <- dm[1]    ;    d <- dm[2]
@@ -670,7 +598,7 @@ prophelling.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
    der2 <- crossprod(x * ( ( 0.5 * (.e3/.e8) + sqy - .e6 )/.e8 + ( 0.5/(.e4 * .e6) - 2 * .e6 ) * 
            .e4 * .e3 * ( sqy - .e6)/.e8^2 ) * .e3, x)
    be <- be - solve(der2, der)
-   .e3 <- as.vector( exp(-x %*% be) )
+   .e3 <- as.vector( exp( x %*% (-be) ) )
    .e4 <- 1 + .e3
    .e6 <- sqrt(1/.e4)
    d2 <- sum( ( sqy - .e6 )^2 )
@@ -684,13 +612,20 @@ prophelling.reg <- function(y, x, tol = 1e-07, maxiters = 100) {
     der2 <- crossprod(x * ( ( 0.5 * (.e3/.e8) + sqy - .e6 )/.e8 + ( 0.5/(.e4 * .e6) - 2 * .e6 ) * 
            .e4 * .e3 * ( sqy - .e6)/.e8^2 ) * .e3, x)
     be <- be - solve(der2, der)
-    .e3 <- as.vector( exp(-x %*% be) )
+    .e3 <- as.vector( exp( x %*% (-be) ) )
     .e4 <- 1 + .e3
     .e6 <- sqrt(1/.e4)
     d2 <- sum( ( sqy - .e6 )^2 )
   } 
 
-  list(be = be, der2 = der2, H = d2, iters = i) 
+  if (cov) {
+    A <- crossprod(x * .e3 * (sqy - .e6) / (.e4^2 * .e6) )
+	B <- solve(der2)
+    covb <- B %*% A %*% B
+    seb <- sqrt( diag(covb) ) 	
+  }	
+  names(be) <- colnames(x)
+  list(be = be, seb = seb, covb = covb, H = d2, iters = i) 
 }
 
 
@@ -710,6 +645,23 @@ censweib.reg <- function (y, x, di, tol = 1e-07, maxiters = 100) {
 }
 
 
+
+
+#[export]
+zigamma.reg <- function(y, x, full = FALSE, tol = 1e-07, maxiters = 100) {
+ y1 <- y
+ id <- which(y > 0)
+ y1[id] <- 1
+ prob <- Rfast::glm_logistic(x, y1, full = full, tol = tol, maxiters = maxiters)
+ rownames(prob$be) <- colnames(x)
+ x <- model.matrix(y~., data = as.data.frame(x) )
+ mod <- Rfast2::gammareg(y[id], x[id, -1, drop = FALSE], tol = tol, maxiters = maxiters)
+ colnames(mod$be) <- colnames(x) 
+ list(prob = prob, mod = mod)
+}
+
+
+
      
    
   
