@@ -34,11 +34,13 @@ SEXP Rfast2_colspml_mle(SEXP xSEXP, SEXP tolSEXP,SEXP maxitersSEXP,SEXP parallel
 SEXP Rfast2_colcauchy_mle(SEXP XSEXP,SEXP tolSEXP,SEXP parallelSEXP,SEXP maxitersSEXP);
 SEXP Rfast2_colbeta_mle(SEXP XSEXP,SEXP tolSEXP,SEXP parallelSEXP,SEXP maxitersSEXP);
 SEXP Rfast2_censweib_reg(SEXP YSEXP,SEXP XSEXP,SEXP diSEXP,SEXP tolSEXP,SEXP maxitersSEXP);
+//SEXP Rfast2_frechet2_c(SEXP XSEXP, SEXP DiSEXP, SEXP aSEXP, SEXP k1SEXP);
 SEXP Rfast2_fbed_reg(SEXP ySEXP,SEXP xSEXP,SEXP sigSEXP,SEXP typeSEXP,SEXP idSEXP,SEXP kSEXP,SEXP backwardSEXP, SEXP tolSEXP,SEXP parallelSEXP,SEXP maxitersSEXP);
 SEXP Rfast2_multinom_reg(SEXP ySEXP,SEXP x0SEXP, SEXP tolSEXP,SEXP maxitersSEXP);
 SEXP Rfast2_weib_regs(SEXP ySEXP,SEXP xSEXP, SEXP tolSEXP,SEXP loggedSEXP,SEXP maxitersSEXP, SEXP parallelSEXP);
 SEXP Rfast2_welch_tests(SEXP xSEXP, SEXP ySEXP, SEXP loggedSEXP, SEXP parallelSEXP);
 SEXP Rfast2_negbin_reg(SEXP ySEXP, SEXP xSEXP, SEXP tolSEXP, SEXP maxitersSEXP);
+SEXP Rfast2_negbin_regs(SEXP ySEXP, SEXP xSEXP, SEXP tolSEXP, SEXP maxitersSEXP, SEXP parallelSEXP);
 SEXP Rfast2_gamma_regs(SEXP YSEXP, SEXP XSEXP,SEXP tolSEXP,SEXP loggedSEXP,SEXP parallelSEXP,SEXP maxitersSEXP);
 SEXP Rfast2_gamma_reg(SEXP YSEXP, SEXP XSEXP,SEXP modSEXP,SEXP tolSEXP,SEXP maxitersSEXP);
 
@@ -69,10 +71,12 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast2_colbeta_mle", (DL_FUNC) &Rfast2_colbeta_mle, 4},
   {"Rfast2_censweib_reg", (DL_FUNC) &Rfast2_censweib_reg, 5},
   {"Rfast2_fbed_reg", (DL_FUNC) &Rfast2_fbed_reg, 10},
+  //{"Rfast2_frechet2_c", (DL_FUNC) &Rfast2_frechet2_c, 4},
   {"Rfast2_multinom_reg", (DL_FUNC) &Rfast2_multinom_reg, 4},
   {"Rfast2_weib_regs", (DL_FUNC) &Rfast2_weib_regs, 6},
   {"Rfast2_welch_tests", (DL_FUNC) &Rfast2_welch_tests, 4},
   {"Rfast2_negbin_reg", (DL_FUNC) &Rfast2_negbin_reg, 4},
+  {"Rfast2_negbin_regs", (DL_FUNC) &Rfast2_negbin_regs, 5},
   {"Rfast2_gamma_regs", (DL_FUNC) &Rfast2_gamma_regs, 6},
   {"Rfast2_gamma_reg", (DL_FUNC) &Rfast2_gamma_reg, 5},
   {NULL, NULL, 0}
